# Generated by roxygen2: do not edit by hand

S3method(st_area,dbSpatial)
S3method(st_as_geojson,dbSpatial)
S3method(st_as_sf,dbSpatial)
S3method(st_as_text,dbSpatial)
S3method(st_bbox,dbSpatial)
S3method(st_buffer,dbSpatial)
S3method(st_centroid,dbSpatial)
S3method(st_geometry_type,dbSpatial)
S3method(st_is_valid,dbSpatial)
S3method(st_join,dbSpatial)
S3method(st_length,dbSpatial)
S3method(st_perimeter,dbSpatial)
S3method(st_simplify,dbSpatial)
export(as_dbSpatial)
export(dbSpatial)
export(loadSpatial)
export(st_as_geojson)
export(st_geometrytype)
export(st_npoints)
export(st_translate)
export(st_x)
export(st_xmax)
export(st_y)
export(st_ymax)
exportClasses(dbSpatial)
exportMethods("$")
exportMethods(head)
exportMethods(tail)
exportMethods(vect)
import(e1071)
import(lifecycle)
import(methods)
importClassesFrom(dbProject,dbData)
importFrom(dbProject,.check_con)
importFrom(dbProject,.check_name)
importFrom(dbProject,.check_overwrite)
importFrom(dbProject,.check_tbl)
importFrom(dbplyr,remote_con)
importFrom(dbplyr,sql_render)
importFrom(sf,st_area)
importFrom(sf,st_as_sf)
importFrom(sf,st_as_text)
importFrom(sf,st_bbox)
importFrom(sf,st_buffer)
importFrom(sf,st_centroid)
importFrom(sf,st_contains)
importFrom(sf,st_covered_by)
importFrom(sf,st_covers)
importFrom(sf,st_crosses)
importFrom(sf,st_disjoint)
importFrom(sf,st_equals)
importFrom(sf,st_geometry_type)
importFrom(sf,st_intersects)
importFrom(sf,st_is_valid)
importFrom(sf,st_is_within_distance)
importFrom(sf,st_join)
importFrom(sf,st_length)
importFrom(sf,st_overlaps)
importFrom(sf,st_perimeter)
importFrom(sf,st_read)
importFrom(sf,st_simplify)
importFrom(sf,st_touches)
importFrom(sf,st_within)
importFrom(terra,vect)
importFrom(tidyselect,all_of)
importFrom(tidyselect,everything)
