% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R
\name{st_perimeter}
\alias{st_perimeter}
\title{Get perimeter of geometries}
\arguments{
\item{x}{\code{\link{dbSpatial}} object}

\item{geomName}{\code{character string}. The geometry column name. Default: \code{"geom"}.}

\item{...}{additional arguments passed to methods}
}
\value{
\code{\link{dbSpatial}} object (lazy tibble with perimeter column)
}
\description{
Returns the perimeter of the geometry column.
}
\examples{
\donttest{
if (interactive() && requireNamespace("duckdb", quietly = TRUE)) {
  square <- sf::st_sf(
    id = 1,
    geom = sf::st_sfc(
      sf::st_polygon(list(rbind(
        c(0, 0), c(1, 0), c(1, 1), c(0, 1), c(0, 0)
      )))
    )
  )
  duckdb_conn <- DBI::dbConnect(duckdb::duckdb(), ":memory:")
  DBI::dbExecute(duckdb_conn, "SET threads = 1")
  x <- as_dbSpatial(square, conn = duckdb_conn, name = "square",
                    overwrite = TRUE)
  st_perimeter(x)
  DBI::dbDisconnect(duckdb_conn, shutdown = TRUE)
}
}
}
\seealso{
Other measurements: 
\code{\link{st_area}()},
\code{\link{st_length}()}
}
\concept{measurements}
