% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/loadSpatial.R
\name{loadSpatial}
\alias{loadSpatial}
\title{Install and/or load DuckDB spatial extension}
\usage{
loadSpatial(conn)
}
\arguments{
\item{conn}{duckdb connection}
}
\value{
No return value, called for side effects. Installs and loads the
DuckDB spatial extension for \code{conn}.
}
\description{
Install and/or load DuckDB spatial extension
}
\examples{
if (interactive() && requireNamespace("duckdb", quietly = TRUE)) {
  duckdb_conn = DBI::dbConnect(duckdb::duckdb(), ":memory:")
  DBI::dbExecute(duckdb_conn, "SET threads = 1")
  loadSpatial(conn = duckdb_conn)
  DBI::dbDisconnect(duckdb_conn, shutdown = TRUE)
}
}
\concept{duckdb-ext}
