% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R
\name{st_buffer}
\alias{st_buffer}
\title{Compute buffer around geometry}
\arguments{
\item{x}{\code{\link{dbSpatial}} object}

\item{dist}{numeric distance}

\item{...}{additional arguments}
}
\value{
\code{\link{dbSpatial}} object with buffered geometry
}
\description{
Returns a geometry that represents all points whose distance from this Geometry is less than or equal to distance.
}
\examples{
\donttest{
if (interactive() && requireNamespace("duckdb", quietly = TRUE)) {
  point <- sf::st_sf(id = 1, geom = sf::st_sfc(sf::st_point(c(0, 0))))
  duckdb_conn <- DBI::dbConnect(duckdb::duckdb(), ":memory:")
  DBI::dbExecute(duckdb_conn, "SET threads = 1")
  x <- as_dbSpatial(point, conn = duckdb_conn, name = "point",
                    overwrite = TRUE)
  st_buffer(x, dist = 1)
  DBI::dbDisconnect(duckdb_conn, shutdown = TRUE)
}
}
}
\seealso{
Other geometry_ops: 
\code{\link{st_centroid}()},
\code{\link{st_simplify}()}
}
\concept{geometry_ops}
