% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extract.R
\name{$,dbSpatial-method}
\alias{$,dbSpatial-method}
\title{Column extraction for dbSpatial}
\usage{
\S4method{$}{dbSpatial}(x, name)
}
\arguments{
\item{x}{A dbSpatial object}

\item{name}{Column name to extract}
}
\value{
A vector of values from the specified column
}
\description{
Extract a column from a dbSpatial object
}
