% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/show.R
\name{show,dbSpatial-method}
\alias{show,dbSpatial-method}
\title{show method for dbSpatial}
\usage{
\S4method{show}{dbSpatial}(object)
}
\arguments{
\item{object}{A \code{dbSpatial} object.}
}
\description{
Show method for dbSpatial
}
\seealso{
Other dbSpatial: 
\code{\link{as_dbSpatial}()},
\code{\link{dbSpatial}},
\code{\link{st_as_sf.dbSpatial}()},
\code{\link{vect,dbSpatial-method}}
}
\concept{dbSpatial}
