% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/st_ymax.R
\name{st_ymax}
\alias{st_ymax}
\alias{st_ymax,dbSpatial-method}
\title{Get maximum y coordinate}
\usage{
st_ymax(dbSpatial, geomName = "geom", ...)

\S4method{st_ymax}{dbSpatial}(dbSpatial, geomName = "geom", ...)
}
\arguments{
\item{dbSpatial}{\code{\link{dbSpatial}} object.}

\item{geomName}{\code{character string}. The geometry column name in the  \code{\link{dbSpatial}}  object. Default: \code{"geom"}.}

\item{...}{additional arguments passed to methods}
}
\value{
numerical column vector in database
}
\description{
This function returns the maximum y coordinate of the geometries in the specified \code{\link{dbSpatial}}  object.
}
\section{Functions}{
\itemize{
\item \code{st_ymax(dbSpatial)}: Method for \code{dbSpatial} object

}}
\examples{
if (interactive() && requireNamespace("duckdb", quietly = TRUE)) {
  # Create a data.frame with x and y coordinates and attributes
  coordinates <- data.frame(x = c(100, 200, 300), y = c(500, 600, 700))
  attributes <- data.frame(id = 1:3, name = c("A", "B", "C"))

  # Combine the coordinates and attributes
  dummy_data <- cbind(coordinates, attributes)

  # Create a duckdb connection
  con = DBI::dbConnect(duckdb::duckdb(), ":memory:")
  DBI::dbExecute(con, "SET threads = 1")

  # Create a duckdb table with spatial points
  db_points = dbSpatial(conn = con,
                        value = dummy_data,
                        x_colName = "x",
                        y_colName = "y",
                        name = "foo",
                        overwrite = TRUE)

  st_ymax(dbSpatial = db_points)
  DBI::dbDisconnect(con, shutdown = TRUE)
}
}
\seealso{
Other geom_summary: 
\code{\link{st_bbox}()},
\code{\link{st_xmax}()}
}
\concept{geom_summary}
