% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extract.R
\name{head,dbSpatial-method}
\alias{head,dbSpatial-method}
\title{head method for dbSpatial}
\usage{
\S4method{head}{dbSpatial}(x, n = 6L, ...)
}
\arguments{
\item{x}{A \code{dbSpatial} object.}

\item{n}{Number of rows to return.}

\item{...}{Additional arguments.}
}
\value{
A \code{dbSpatial} object containing the first \code{n} rows of \code{x}.
}
\description{
head method for dbSpatial
}
\seealso{
Other dbData: 
\code{\link{tail,dbSpatial-method}}
}
\concept{dbData}
