% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sim_dbSpatial.R
\name{.sim_dbSpatial}
\alias{.sim_dbSpatial}
\title{Simulate basic dbSpatial object}
\usage{
.sim_dbSpatial(geom = c("point", "polygon"))
}
\arguments{
\item{geom}{whether to load 'point' or 'polygon' GEOMETRY test file}
}
\value{
A dbSpatial object
}
\description{
Simulate basic dbSpatial object
}
\details{
Polygon data is created dynamically using sf rather than loading
from inst/extdata/polygon.geojson. This avoids issues with system.file()
returning an empty string when called from dependent packages during
R CMD check (before dbSpatial is fully installed to the test library).
}
\keyword{internal}
