% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/st_bbox.R
\name{st_bbox}
\alias{st_bbox}
\alias{st_bbox.dbSpatial}
\title{Compute bounding box for dbSpatial object}
\usage{
\method{st_bbox}{dbSpatial}(obj, ...)
}
\arguments{
\item{obj}{\code{\link{dbSpatial}} object}

\item{...}{additional arguments passed to methods}
}
\value{
\code{bbox} object (named numeric vector with xmin, ymin, xmax, ymax)
}
\description{
Returns the bounding box of the geometry column.
}
\seealso{
Other geom_summary: 
\code{\link{st_xmax}()},
\code{\link{st_ymax}()}
}
\concept{geom_summary}
